@@ -22,7 +22,8 @@ def start_interactive(args):
     :param args: command line arguments evaluated with argparse.
     '''
     debug('enter start_interactive')
-    if sys.platform=='darwin' and not sys.executable.endswith('MacOS/Python'):
+    if sys.version_info < (3, 9) and sys.platform=='darwin' and not sys.executable.endswith('MacOS/Python'):
+        # restart with pythonw, this should not be necessary for newer python versions
         debug('detected Mac OS run without pythonw, re-run with correct executable')
         debug(' '.join(['pythonw', '-m', 'genx.run']+sys.argv[1:]))
         logger = getLogger()
